==> gazie7.30.zip: gazie/modules/inform/menu.english.php <==
<?php

/*
  --------------------------------------------------------------------------
  GAzie - Gestione Azienda
  Copyright (C) 2004-2020 - Antonio De Vincentiis Montesilvano (PE)
  (http://www.devincentiis.it)
  <http://gazie.sourceforge.net>
  --------------------------------------------------------------------------
  Questo programma e` free software;   e` lecito redistribuirlo  e/o
  modificarlo secondo i  termini della Licenza Pubblica Generica GNU
  come e` pubblicata dalla Free Software Foundation; o la versione 2
  della licenza o (a propria scelta) una versione successiva.

  Questo programma  e` distribuito nella speranza  che sia utile, ma
  SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
  NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
  veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

  Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
  Generica GNU insieme a   questo programma; in caso  contrario,  si
  scriva   alla   Free  Software Foundation, 51 Franklin Street,
  Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
  --------------------------------------------------------------------------
 */
$transl['inform'] = array('name' => "Tools & Info",
    'title' => "Tools and information",
    'm2' => array(1 => array("Select and print letter", "Letter"),
        2 => array("Select and print letterhead", "Letterhead"),
        3 => array("Lista dei salvataggi su server", "Backups"),
        4 => array("Control for new version", "Update"),
        5 => array("Update website", "Update website"),
        6 => array("Rubrica URL", "Siti Aziendali"), 
        7 => array("Anagrafiche comuni a tutte le aziende", "Anagrafiche comuni")
    ),
    'm3' => array(1 => array("Controllo sbilancio dare-avere dei movimenti contabili", "Controllo sbilancio movimenti contabili"),
        2 => array("Controllo numerazione protocolli IVA", "Controllo numerazione protocolli IVA"),
        3 => array("Write a new letter", "New letter"),
        4 => array("Gestisci URL", "Gestione Siti"),
        5 => array("Aggiungi URL", "Aggiungi Sito"),
        6 => array("Aggiorna GAzieCart", "Aggiorna GAzieCart"),
        7 => array("Aggiorna sito web", "Crea/aggiorna sito Statico"),
        8 => array("Backup su browser", "Backup remoto"),
        9 => array("Backup su server","Backup locale"),
        10 => array("Anagrafiche clienti-fornitori", "Anagrafiche clienti-fornitori"),
        11 => array("Comuni","Municipalità"),
        12 => array("Province","Province")

    )
);
?>

==> gazie8.00.zip: gazie/modules/inform/menu.english.php <==
<?php

/*
  --------------------------------------------------------------------------
  GAzie - Gestione Azienda
  Copyright (C) 2004-2021 - Antonio De Vincentiis Montesilvano (PE)
  (http://www.devincentiis.it)
  <http://gazie.sourceforge.net>
  --------------------------------------------------------------------------
  Questo programma e` free software;   e` lecito redistribuirlo  e/o
  modificarlo secondo i  termini della Licenza Pubblica Generica GNU
  come e` pubblicata dalla Free Software Foundation; o la versione 2
  della licenza o (a propria scelta) una versione successiva.

  Questo programma  e` distribuito nella speranza  che sia utile, ma
  SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
  NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
  veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

  Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
  Generica GNU insieme a   questo programma; in caso  contrario,  si
  scriva   alla   Free  Software Foundation, 51 Franklin Street,
  Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
  --------------------------------------------------------------------------
 */
$transl['inform'] = array('name' => "Tools & Info",
    'title' => "Tools and information",
    'm2' => array(1 => array("Select and print letter", "Letter"),
        2 => array("Select and print letterhead", "Letterhead"),
        3 => array("Lista dei salvataggi su server", "Backups"),
        4 => array("Control for new version", "Update"),
        5 => array("Update website", "Update website"),
        6 => array("Rubrica URL", "Siti Aziendali"), 
        7 => array("Anagrafiche comuni a tutte le aziende", "Anagrafiche comuni")
    ),
    'm3' => array(1 => array("Controllo sbilancio dare-avere dei movimenti contabili", "Controllo sbilancio movimenti contabili"),
        2 => array("Controllo numerazione protocolli IVA", "Controllo numerazione protocolli IVA"),
        3 => array("Write a new letter", "New letter"),
        4 => array("Gestisci URL", "Gestione Siti"),
        5 => array("Aggiungi URL", "Aggiungi Sito"),
        6 => array("Aggiorna GAzieCart", "Aggiorna GAzieCart"),
        7 => array("Aggiorna sito web", "Crea/aggiorna sito Statico"),
        8 => array("Backup su browser", "Backup remoto"),
        9 => array("Backup su server","Backup locale"),
        10 => array("Anagrafiche clienti-fornitori", "Anagrafiche clienti-fornitori"),
        11 => array("Comuni","Municipalità"),
        12 => array("Province","Province"),
        13 => array("Bank branches","Bank branches")

    )
);
?>
